@@ -211,7 +211,9 @@ impl<S: Integer> Vector<S> for Vec4d<S> {
         Vec4d([f(0), f(1), f(2), f(3)])
     }
 
-    /// The L1, taxicab or Manhatten norm.
+    /// Returns the L1 norm of the vector.
+    ///
+    /// This is also called the taxicab, Manhatten or city block norm.
     fn norm_l1(&self) -> S {
         let abs_x = self.x().abs();
         let abs_y = self.y().abs();
@@ -219,8 +221,9 @@ impl<S: Integer> Vector<S> for Vec4d<S> {
         let abs_w = self.w().abs();
         abs_x + abs_y + abs_z + abs_w
     }
-
-    /// The maximum, Chebychev or L-infinity norm.
+    /// Returns the L∞ norm of the vector.
+    ///
+    /// This is also called the maximum or Chebychev norm.
     fn norm_l_infty(&self) -> S {
         let abs_x = self.x().abs();
         let abs_y = self.y().abs();
@@ -228,6 +231,18 @@ impl<S: Integer> Vector<S> for Vec4d<S> {
         let abs_w = self.w().abs();
         abs_x.max(abs_y).max(abs_z).max(abs_w)
     }
+    /// Returns the square of the L2-norm of the vector.
+    ///
+    /// The L2-norm is also called the Euclidean norm and
+    /// is the standard notion of the length of a vector.
+    fn norm_l2_squared(&self) -> S {
+        let x = self.x();
+        let y = self.y();
+        let z = self.z();
+        let w = self.w();
+        x * x + y * y + z * z + w * w
+    }
+
     /// Creates a vector of the 80 vectors with L∞ norm equal to 1.
     fn unit_vecs_l_infty() -> Vec<Self> {
         let mut result = Vec::new();
@@ -625,6 +640,11 @@ mod tests {
         assert_eq!(8, v4d(2, 3, 5, 8).norm_l_infty());
         assert_eq!(8, v4d(-2, -3, -5, -8).norm_l_infty());
     }
+    #[test]
+    fn test_norm_l2_squared() {
+        assert_eq!(102, v4d(2, 3, 5, 8).norm_l2_squared());
+        assert_eq!(102, v4d(-2, -3, -5, -8).norm_l2_squared());
+    }
 
     #[test]
     fn test_debug() {
